searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"RetryOnStale.html","title":"RetryOnStale","type":"module"},{"doc":"","ref":"RetryOnStale.html#retry_on_stale/2","title":"RetryOnStale.retry_on_stale/2","type":"function"},{"doc":"# RetryOnStale\r\n\r\n`retry_on_stale/2` performs an operation that might raise an `Ecto.StaleEntryError` and retries\r\nit a specified number of times with a delay between each attempt.","ref":"readme.html","title":"RetryOnStale","type":"extras"},{"doc":"The example features a wallet's `balance_amount`, protected by [optimistic locking](https://hexdocs.pm/ecto/Ecto.Changeset.html#optimistic_lock/3) to prevent race conditions. The `retry_on_stale/2` function handles `Ecto.StaleEntryError` from concurrent transactions, refetching the wallet and retrying the operation.\r\n\r\n```elixir\r\nimport RetryOnStale, only: [retry_on_stale: 2]\r\n\r\ndef increase_wallet_balance(%Wallet{} = wallet, amount) do\r\n  retry_on_stale(\r\n    fn attempt ->\r\n      # refetch the latest wallet data for subsequent attempts\r\n      wallet = if attempt == 1, do: wallet, else: Repo.get!(Wallet, wallet.id)\r\n\r\n      # this function could raise a StaleEntryError\r\n      do_increase_wallet_balance(wallet, amount)\r\n    end,\r\n    max_attempts: 5, delay_ms: 100\r\n  )\r\nend\r\n\r\ndefp do_increase_wallet_balance(%Wallet{} = wallet, amount) do\r\n  new_balance = Decimal.add(wallet.balance_amount, amount)\r\n\r\n  wallet\r\n  |> Ecto.Changeset.change(balance_amount: new_balance)\r\n  |> Ecto.Changeset.optimistic_lock(:lock_version)\r\n  |> Repo.update!()\r\nend\r\n```","ref":"readme.html#example","title":"Example - RetryOnStale","type":"extras"},{"doc":"`:max_attempts` - The maximum number of attempts to perform the operation\r\nbefore giving up and re-raising the last Ecto.StaleEntryError.\r\n\r\n`:delay_ms` - The delay in milliseconds between each attempt.","ref":"readme.html#options","title":"Options - RetryOnStale","type":"extras"},{"doc":"Add `retry_on_stale` for Elixir as a dependency in your `mix.exs` file:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:retry_on_stale, \"~> 0.2.0\"}\r\n  ]\r\nend\r\n```","ref":"readme.html#installation","title":"Installation - RetryOnStale","type":"extras"},{"doc":"HexDocs documentation can be found at [https://hexdocs.pm/retry_on_stale](https://hexdocs.pm/retry_on_stale).","ref":"readme.html#hexdocs","title":"HexDocs - RetryOnStale","type":"extras"}]}